@@ -253,7 +253,7 @@
 #define INSTALL_SCRIPTDIR "/usr/local/mysql/bin"
 #define INSTALL_MYSQLDATADIR "/usr/local/mysql/data"
 #define INSTALL_MYSQLKEYRINGDIR "/usr/local/mysql/keyring"
-#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.19-17/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.19-17/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.19-17/plugin/scalability_metrics/tests"
+#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.20-19/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.20-19/plugin/keyring_vault/tests;/build/percona-server/src/percona-server-5.7.20-19/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.20-19/plugin/scalability_metrics/tests"
 #define INSTALL_INFODIR "/usr/local/mysql/share/mysql/docs"
 #define INSTALL_MYSQLTESTDIR "/usr/local/mysql/mysql-test"
 #define INSTALL_DOCREADMEDIR "/usr/local/mysql/share/mysql"
@@ -274,8 +274,7 @@
 /* #undef HAVE_NCURSES_H */
 #define USE_LIBEDIT_INTERFACE 1
 #define HAVE_HIST_ENTRY 1
-/* #undef USE_NEW_EDITLINE_INTERFACE */
-#define USE_NEW_READLINE_INTERFACE 1
+#define USE_NEW_XLINE_INTERFACE 1
 #define HAVE_READLINE_HISTORY_H 1
 
 /*
@@ -391,15 +390,15 @@
 #define DOT_FRM_VERSION 6
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 7
-#define MYSQL_VERSION_PATCH 19
-#define MYSQL_VERSION_EXTRA "-17"
+#define MYSQL_VERSION_PATCH 20
+#define MYSQL_VERSION_EXTRA "-19"
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.7.19-17"
+#define PACKAGE_STRING "MySQL Server 5.7.20-19"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.7.19-17"
-#define VERSION "5.7.19-17"
+#define PACKAGE_VERSION "5.7.20-19"
+#define VERSION "5.7.20-19"
 #define PROTOCOL_VERSION 10
 
 /*
